@@ -11,4 +11,11 @@ def accuracy(targets, outputs):
             accuracy = np.array(np.sum(np.around(outputs[:,i]) == targets[:,i]) / len(targets[:,i]))
             return accuracy
         else:
-            accuracy = np.array(np.sum(np.around(outputs[:,i]) == targets[:,i]) / len(targets[:,i])) * np.array(np.sum(np.around(outputs[:,i+1]) == targets[:,i+1]) / len(targets[:,i+1]))
\ No newline at end of file
+            accuracy = np.array(np.sum(np.around(outputs[:,i]) == targets[:,i]) / len(targets[:,i])) * np.array(np.sum(np.around(outputs[:,i+1]) == targets[:,i+1]) / len(targets[:,i+1]))
+
+def differences(targets, outputs):
+    for i in range(len(outputs)):
+        if outputs[i] >= targets[i]:
+            print(outputs[i] - targets[i])
+        if outputs[i] < targets[i]:
+            print(targets[i] - outputs[i])
\ No newline at end of file
